#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.2.4.1
id: persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
key: persi_FsSRrdTzyvp1qGLhPcIYzr
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
hs-libraries: HSpersistent-2.2.4.1-FsSRrdTzyvp1qGLhPcIYzr
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
    http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-f3d00babf6bfa7ff698db362dc267041
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
    resource-pool-0.2.3.2-4273363c3eb17da3d6b84d801cb4d318
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    silently-1.2.5-7f926db5f44f7696c1a8c4ab976d4845
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
